# Game-system contribs

Other specific gameplay system, not necessesarily related to roleplay.

Many of these system are commonly used in RPGs, to decide what goes here and in
the `rpg/` folder, consider if these systems could _theoretically_ be used in a
non-rpg MMO.
